### Name: AdjAR
### Title: Calling the estimation of the (adjusted) attributable risks from
###   case-control data
### Aliases: AdjAR
### Keywords: manip

### ** Examples


##### Computation of the AR for every combination of two #####
##### exposure factors if there are no confounders       #####

set.seed(2007)
dicho        <- c(0,1)
cc_state     <- sample(dicho, 100, replace=TRUE)
exposure1    <- sample(dicho, 100, replace=TRUE, prob=c(0.7, 0.3))
exposure2    <- sample(dicho, 100, replace=TRUE, prob=c(0.4, 0.6))
relation     <- as.formula(cc_state~exposure1+exposure2)
data_exp     <- cbind(exposure1, exposure2)
AR_exposures <- AdjAR(D=cc_state, E=data_exp, model=relation)

##### Computation of the AR for every combination of two #####
##### exposure factors with adjustment to confounder1    #####

set.seed(2008)
cc_state        <- sample(dicho, 100, replace=TRUE)
exposure1       <- sample(dicho, 100, replace=TRUE, prob=c(0.7, 0.3))
exposure2       <- sample(dicho, 100, replace=TRUE, prob=c(0.4, 0.6))
cat_confounder  <- c(0,1,2,3)
confounder1     <- sample(cat_confounder, 100, replace=TRUE)
data_exp        <- cbind(exposure1, exposure2)
conf            <- matrix(confounder1, ncol=1)
colnames(conf)  <- c("confounder1")
rel_mod         <- glm(cc_state~exposure1+exposure2+confounder1,
                       family=binomial)
AR_exposures    <- AdjAR(cc_state, data_exp, conf, rel_mod)





