### Name: Boot_CI
### Title: Bootstrap confidence intervals for partial attributable risks
###   (PAR) from case-control data
### Aliases: Boot_CI
### Keywords: manip

### ** Examples


###### Computation of BCa confidence intervals #######
###### for the PAR if there are no confounders #######

set.seed(2007)
dicho           <- c(0,1)
cc_state        <- sample(dicho, 100, replace=TRUE)
exposure1       <- sample(dicho, 100, replace=TRUE, prob=c(0.7, 0.3))
exposure2       <- sample(dicho, 100, replace=TRUE, prob=c(0.4, 0.6))
relation        <- as.formula(cc_state~exposure1+exposure2)
data_exp        <- cbind(exposure1, exposure2)
PAR_exposures   <- PAR(cc_state, data_exp, model=relation)
CI_95           <- Boot_CI(D=cc_state, E=data_exp, model=relation, 
                           nboot=70,original=PAR_exposures, type="bca")

###### Computation of percentile confidence intervals #######
###### for the PAR if there are confounders           #######

set.seed(2008)
dicho           <- c(0,1)
cc_state        <- sample(dicho, 100, replace=TRUE)
exposure1       <- sample(dicho, 100, replace=TRUE, prob=c(0.7, 0.3))
exposure2       <- sample(dicho, 100, replace=TRUE, prob=c(0.4, 0.6))
cat_confounder  <- c(0,1,2,3)
confounder1     <- sample(cat_confounder, 100, replace=TRUE)
relation        <- as.formula(cc_state~exposure1+exposure2+confounder1)
data_exp        <- cbind(exposure1, exposure2)
conf            <- matrix(confounder1, ncol=1)
colnames(conf)  <- c("confounder1")
PAR_exposures   <- PAR(cc_state, data_exp, conf, model=relation)
CI_95           <- Boot_CI(D=cc_state, E=data_exp, C=conf, model=relation, 
                           nboot=70,original=PAR_exposures)




